@@ -2,6 +2,14 @@
 package Net::Amazon::Request;
 ######################################################################
 
+our $AMZN_XML_URL     = "http://xml.amazon.com/onca/xml2";
+
+##################################################
+sub amzn_xml_url {
+##################################################
+    return $AMZN_XML_URL;
+}
+
 ##################################################
 sub new {
 ##################################################
